#
# spec file for package hibernate5
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _build_modules 1
%global mvn_pomdir /usr/share/maven-poms
%global mvn_metadir /usr/share/maven-metadata

Name:           hibernate5
Version:        5.3.25
Release:        9.10
License:        LGPL-2.1-only
Summary:        Hibernate ORM is a component/library providing Object/Relational Mapping (ORM)
URL:            http://hibernate.org
Group:          Development/Libraries/Java
Source0:        hibernate-orm-5.3.25.tar.gz
Source1:        build.sh

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires: mvn(junit:junit)
BuildRequires: xmvn-tools
BuildRequires: xmvn-minimal
BuildRequires:  java-devel >= 1.9
BuildRequires:  javapackages-local
%if 0%{?rhel} >= 9
BuildRequires:  xmvn-tools
%else
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
%endif
BuildRequires:  xz
BuildRequires:  mvn(antlr:antlr)
BuildRequires:  mvn(com.fasterxml:classmate)
BuildRequires:  mvn(com.mchange:c3p0)
BuildRequires:  mvn(javax.activation:javax.activation-api)
BuildRequires:  mvn(javax.cache:cache-api)
BuildRequires:  mvn(javax.xml.bind:jaxb-api)
BuildRequires:  mvn(net.bytebuddy:byte-buddy) <= 1.12.0
BuildRequires:  mvn(org.apache.logging.log4j:log4j-core)
BuildRequires:  mvn(org.dom4j:dom4j)
BuildRequires:  mvn(org.glassfish.jaxb:jaxb-runtime)
BuildRequires:  mvn(org.hibernate.common:hibernate-commons-annotations)
BuildRequires:  mvn(org.javassist:javassist)
BuildRequires:  mvn(org.jboss.logging:jboss-logging)
BuildRequires:  mvn(org.jboss:jandex)
BuildRequires:  mvn(org.osgi:org.osgi.compendium)
BuildRequires:  mvn(org.osgi:org.osgi.core)
BuildRequires:  mvn(org.postgresql:postgresql)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.sonatype.plexus:plexus-build-api)

BuildArch:      noarch
ExcludeArch:    aarch64 ppc64le s390x
Requires:       classmate
Requires:       java
Requires:       jboss-logging

%if 0%{?rhel}
BuildRequires:  java-11-openjdk-devel
%endif

%description
Hibernate ORM enables developers to more easily write applications whose data outlives the application process. As an Object/Relational Mapping (ORM) framework, Hibernate is concerned with data persistence as it applies to relational databases (via JDBC).

%if 0%{?_build_modules}
%package core
Summary:        Hibernate ORM - hibernate-core

%description core
Hibernate's core ORM functionality

%package agroal
Summary:        Hibernate ORM - hibernate-agroal

%description agroal
Integration for Agroal as a ConnectionProvider for Hibernate ORM

%package c3p0
Summary:        Hibernate ORM - hibernate-c3p0

%description c3p0
Integration for c3p0 Connection pooling into Hibernate ORM

%package ehcache
Summary:        Hibernate ORM - hibernate-ehcache

%description ehcache
Integration for using Ehcache 2.x as a Hibernate second-level-cache provider

%package entitymanager
Summary:        Hibernate ORM - hibernate-entitymanager

%description entitymanager
(deprecated - use hibernate-core instead) Hibernate O/RM implementation of the JPA specification

%package envers
Summary:        Hibernate ORM - hibernate-envers

%description envers
Hibernate's entity version (audit/history) support

%package hikaricp
Summary:        Hibernate ORM - hibernate-hikaricp

%description hikaricp
Integration for HikariCP into Hibernate O/RM

%package java8
Summary:        Hibernate ORM - hibernate-java8

%description java8
(deprecated - use hibernate-core instead) Support for Java8-specific features - mainly Java8 Date/Time (JSR 310)

%package jcache
Summary:        Hibernate ORM - hibernate-jcache

%description jcache
Integration for javax.cache into Hibernate as a second-level caching service

%package jipijapa
Summary:        Hibernate ORM - hibernate-jipijapa

%description jipijapa
Integrate with WildFly JipiJapa

%package osgi
Summary:        Hibernate ORM - hibernate-osgi

%description osgi
Support for running Hibernate O/RM in OSGi environments

%package proxool
Summary:        Hibernate ORM - hibernate-proxool

%description proxool
Integration for Proxool Connection pooling into Hibernate O/RM

%package spatial
Summary:        Hibernate ORM - hibernate-spatial

%description spatial
Integrate support for Spatial/GIS data into Hibernate O/RM

%package testing
Summary:        Hibernate ORM - hibernate-testing

%description testing
Support for testing Hibernate ORM functionality

%package vibur
Summary:        Hibernate ORM - hibernate-vibur

%description vibur
Integration for Vibur Connection pooling as a Hibernate ORM ConnectionProvider

%package enhance-maven-plugin
Summary:        Hibernate ORM - hibernate-enhance-maven-plugin

%description enhance-maven-plugin
Enhance Plugin of the Hibernate project for use with Maven build system.

%package gradle-plugin
Summary:        Hibernate ORM - hibernate-gradle-plugin

%description gradle-plugin
Gradle plugin for integrating Hibernate functionality into your build

%package jpamodelgen
Summary:        Hibernate ORM - hibernate-jpamodelgen

%description jpamodelgen
Annotation Processor to generate JPA 2 static metamodel classes

%endif

%prep
%setup -q -c -n src
cp -f %{SOURCE1} .

%build
cd ..
sh src/build.sh

cd src

%pom_xpath_remove "pom:dependency[pom:artifactId='jboss-transaction-api_1.2_spec']" hibernate-orm-%{version}/hibernate-core/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='hibernate-commons-annotations']" hibernate-orm-%{version}/hibernate-core/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='javax.persistence-api']" hibernate-orm-%{version}/hibernate-core/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='classmate']" hibernate-orm-%{version}/hibernate-core/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='ehcache']" hibernate-orm-%{version}/hibernate-ehcache/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='vibur-dbcp']" hibernate-orm-%{version}/hibernate-vibur/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='jboss-vfs']" hibernate-orm-%{version}/hibernate-jipijapa/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='jipijapa-spi']" hibernate-orm-%{version}/hibernate-jipijapa/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='jboss-transaction-api_1.2_spec']" hibernate-orm-%{version}/hibernate-entitymanager/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='javax.persistence-api']" hibernate-orm-%{version}/hibernate-entitymanager/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='agroal-api']" hibernate-orm-%{version}/hibernate-agroal/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='agroal-pool']" hibernate-orm-%{version}/hibernate-agroal/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='jbossjta']" hibernate-orm-%{version}/hibernate-testing/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='byteman-bmunit']" hibernate-orm-%{version}/hibernate-testing/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='byteman-install']" hibernate-orm-%{version}/hibernate-testing/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='byteman']" hibernate-orm-%{version}/hibernate-testing/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='xapool']" hibernate-orm-%{version}/hibernate-testing/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='jboss-transaction-api_1.2_spec']" hibernate-orm-%{version}/hibernate-testing/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='geolatte-geom']" hibernate-orm-%{version}/hibernate-spatial/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='proxool']" hibernate-orm-%{version}/hibernate-proxool/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='javax.interceptor-api']" hibernate-orm-%{version}/hibernate-osgi/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='HikariCP']" hibernate-orm-%{version}/hibernate-hikaricp/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='jboss-transaction-api_1.2_spec']" hibernate-orm-%{version}/tooling/hibernate-enhance-maven-plugin/target/generated-pom.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='javax.persistence-api']" hibernate-orm-%{version}/tooling/hibernate-enhance-maven-plugin/target/generated-pom.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='javax.persistence-api']" hibernate-orm-%{version}/tooling/hibernate-gradle-plugin/target/generated-pom.xml

%{mvn_package} ":hibernate-core" core
%{mvn_package} ":hibernate-c3p0" c3p0
%{mvn_package} ":hibernate-ehcache" ehcache
%{mvn_package} ":hibernate-jcache" jcache
%{mvn_package} ":hibernate-agroal" agroal
%{mvn_package} ":hibernate-entitymanager" entitymanager
%{mvn_package} ":hibernate-envers" envers
%{mvn_package} ":hibernate-hikaricp" hikaricp
%{mvn_package} ":hibernate-java8" java8
%{mvn_package} ":hibernate-jipijapa" jipijapa
%{mvn_package} ":hibernate-osgi" osgi
%{mvn_package} ":hibernate-proxool" proxool
%{mvn_package} ":hibernate-spatial" spatial
%{mvn_package} ":hibernate-testing" testing
%{mvn_package} ":hibernate-vibur" vibur
%{mvn_package} ":hibernate-enhance-maven-plugin" enhance-maven-plugin
%{mvn_package} ":hibernate-gradle-plugin" gradle-plugin
%{mvn_package} ":hibernate-jpamodelgen" jpamodelgen

for m in hibernate-core hibernate-c3p0 hibernate-ehcache hibernate-jcache hibernate-agroal hibernate-entitymanager hibernate-envers hibernate-hikaricp hibernate-java8 hibernate-jipijapa hibernate-osgi hibernate-proxool hibernate-spatial hibernate-testing hibernate-vibur; do
  cp hibernate-orm-%{version}/$m/target/generated-pom.xml $m.xml
  %{mvn_artifact} $m.xml hibernate-orm-%{version}/$m/target/libs/$m-%{version}.Final.jar
done
for t in hibernate-enhance-maven-plugin hibernate-gradle-plugin; do
  cp hibernate-orm-%{version}/tooling/$t/target/generated-pom.xml $t.xml
  %{mvn_artifact} $t.xml hibernate-orm-%{version}/tooling/$t/target/libs/$t-%{version}.Final.jar
done

cp hibernate-orm-%{version}/tooling/metamodel-generator/target/generated-pom.xml metamodel-generator.xml
%{mvn_artifact} metamodel-generator.xml hibernate-orm-%{version}/tooling/metamodel-generator/target/libs/hibernate-jpamodelgen-%{version}.Final.jar

%install
%mvn_install

%if 0%{?_build_modules}
%files core -f .mfiles-core
%license hibernate-orm-%{version}/lgpl.txt

%files agroal -f .mfiles-agroal
%license hibernate-orm-%{version}/lgpl.txt

%files c3p0 -f .mfiles-c3p0
%license hibernate-orm-%{version}/lgpl.txt

%files ehcache -f .mfiles-ehcache
%license hibernate-orm-%{version}/lgpl.txt

%files entitymanager -f .mfiles-entitymanager
%license hibernate-orm-%{version}/lgpl.txt

%files envers -f .mfiles-envers
%license hibernate-orm-%{version}/lgpl.txt

%files hikaricp -f .mfiles-hikaricp
%license hibernate-orm-%{version}/lgpl.txt

%files java8 -f .mfiles-java8
%license hibernate-orm-%{version}/lgpl.txt

%files jcache -f .mfiles-jcache
%license hibernate-orm-%{version}/lgpl.txt

%files jipijapa -f .mfiles-jipijapa
%license hibernate-orm-%{version}/lgpl.txt

%files osgi -f .mfiles-osgi
%license hibernate-orm-%{version}/lgpl.txt

%files proxool -f .mfiles-proxool
%license hibernate-orm-%{version}/lgpl.txt

%files spatial -f .mfiles-spatial
%license hibernate-orm-%{version}/lgpl.txt

%files testing -f .mfiles-testing
%license hibernate-orm-%{version}/lgpl.txt

%files vibur -f .mfiles-vibur
%license hibernate-orm-%{version}/lgpl.txt

%files enhance-maven-plugin -f .mfiles-enhance-maven-plugin
%license hibernate-orm-%{version}/lgpl.txt

%files gradle-plugin -f .mfiles-gradle-plugin
%license hibernate-orm-%{version}/lgpl.txt

%files jpamodelgen -f .mfiles-jpamodelgen
%license hibernate-orm-%{version}/lgpl.txt

%else

%files -f .mfiles
%license hibernate-orm-%{version}/lgpl.txt

%endif

%changelog
* Mon Jun 13 2022 Michael Calmer <mc@suse.com>
- build subpackages for jar files
* Tue Jun  7 2022 Michael Calmer <mc@suse.com>
- install maven pom files
* Sun Jan 30 2022 Michael Calmer <mc@suse.com>
- Update to version 5.3.25
  * Full changelog available at https://github.com/hibernate/hibernate-orm/blob/b56a3be94ae58196856b411d60708b7627e67052/changelog.txt
- Removed (included in new release):
  * 0001-HHH-14225-CVE-2020-25638-Potential-for-SQL-injection.patch
  * 0001-HHH-14077-CVE-2019-14900-SQL-injection-issue-in-Hibe.patch
* Thu Dec 16 2021 Michael Calmer <mc@suse.com>
- Fix potential SQL injection CVE-2020-25638 (bsc#1193832)
- Added:
  * 0001-HHH-14225-CVE-2020-25638-Potential-for-SQL-injection.patch
* Sat Dec  5 2020 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Added antlr-tool for RHEL.
* Sat Nov 28 2020 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Enhanced for RHEL8
* Wed Aug 12 2020 Silvio Moioli <moio@suse.com>
- Address CVE-2019-14900 (bsc#1172079)
- Add patch:
  * 0001-HHH-14077-CVE-2019-14900-SQL-injection-issue-in-Hibe.patch
* Thu May 30 2019 Julio González Gil <jgonzalez@suse.com>
- Package does not build at aarch64, ppc64le and s390x, so
  build is now disabled, as package is exported from x86_64 to
  such architectures
* Tue Dec 11 2018 moio@suse.com
- Update to version 5.3.7 for JDK 11 compatibility
- Full changelog available at https://github.com/hibernate/hibernate-orm/blob/890a6409a637da6f9fb64e2e11a9b87e01270ee0/changelog.txt#L7-L1283
- Remove:
  * hibernate-orm-5.2.2-src-jdk9.patch (obsoleted)
* Mon Nov 20 2017 jgonzalez@suse.com
- Fix build for JDK9
- Disable javadoc and documentation generation (broken for JDK9)
- Add:
  * hibernate-orm-5.2.2-src-jdk9.patch
* Wed Aug 31 2016 moio@suse.com
- Initial version
